@@ -47,6 +47,8 @@ class P_cif(StructureParser):
     Data members used for input only:
 
     spacegroup  -- instance of SpaceGroup used for symmetry expansion
+    eps         -- resolution in fractional coordinates for non-equal
+                   positions.  Use for expansion of asymmetric unit.
     eau         -- instance of ExpandAsymmetricUnit from SymmetryUtilities
     asymmetric_unit -- list of atom instances for the original asymmetric
                    unit in the CIF file
@@ -92,6 +94,10 @@ class P_cif(StructureParser):
         '_tr_atom_site_aniso_B_13',
         '_tr_atom_site_aniso_B_23',
         ))
+    # make _atom_setters case insensitive
+    for k in _atom_setters.keys():
+        _atom_setters[k] = _atom_setters[k.lower()] = k
+    del k
 
     BtoU = 1.0/(8 * numpy.pi**2)
 
@@ -100,7 +106,7 @@ class P_cif(StructureParser):
     _tr_ignore = staticmethod(_tr_ignore)
 
     def _tr_atom_site_label(a, value):
-        a.label = value
+        a.label = str(value)
         # set element when not specified by _atom_site_type_symbol
         if not a.element:
             P_cif._tr_atom_site_type_symbol(a, value)
@@ -112,6 +118,7 @@ class P_cif(StructureParser):
     def _tr_atom_site_type_symbol(a, value):
         rx = P_cif._psymb.match(value)
         smbl = rx and rx.group(0) or value
+        smbl = str(smbl)
         a.element = smbl[:1].upper() + smbl[1:].lower()
     _tr_atom_site_type_symbol = staticmethod(_tr_atom_site_type_symbol)
 
@@ -215,11 +222,9 @@ class P_cif(StructureParser):
         """
         rv = []
         for p in cifloop.keys():
-            fncname = "_tr" + p
-            if fncname in P_cif._atom_setters:
-                f = getattr(P_cif, fncname)
-            else:
-                f = P_cif._tr_ignore
+            lcname = "_tr" + p.lower()
+            fncname = P_cif._atom_setters.get(lcname, '_tr_ignore')
+            f = getattr(P_cif, fncname)
             rv.append(f)
         return rv
     _get_atom_setters = staticmethod(_get_atom_setters)
@@ -229,12 +234,18 @@ class P_cif(StructureParser):
     # normal methods
     ########################################################################
 
-    def __init__(self):
+    def __init__(self, eps=None):
+        """Initialize the parser for CIF structure files.
+
+        eps  -- fractional coordinates cutoff for duplicate positions.
+                When None use the default for ExpandAsymmetricUnit.
+        """
         StructureParser.__init__(self)
         self.format = "cif"
         self.ciffile = None
         self.stru = None
         self.spacegroup = None
+        self.eps = eps
         self.eau = None
         self.asymmetric_unit = None
         self.labelindex = {}
@@ -277,13 +288,15 @@ class P_cif(StructureParser):
         Raise StructureFormatError or IOError.
         """
         import CifFile
-        from StarFile import StarError
+        fixpycif = _FixPyCifRW()
+        StarError = fixpycif.importStarError()
         # CifFile fails when filename is a unicode string
         if type(filename) is unicode:
             filename = str(filename)
         self.filename = filename
         try:
             fileurl = fixIfWindowsPath(filename)
+            fixpycif.disableParserOutput()
             self.ciffile = CifFile.CifFile(fileurl)
             for blockname, ignore in self.ciffile.items():
                 self._parseCifBlock(blockname)
@@ -293,6 +306,8 @@ class P_cif(StructureParser):
             exc_type, exc_value, exc_traceback = sys.exc_info()
             emsg = str(err).strip()
             raise StructureFormatError, emsg, exc_traceback
+        finally:
+            fixpycif.restoreParserOutput()
         # all good here
         return self.stru
 
@@ -379,6 +394,11 @@ class P_cif(StructureParser):
         No return value.
         """
         if not block.has_key('_atom_site_aniso_label'): return
+        # was anisotropy set in the _atom_site_label loop?
+        atom_site_loop = block.GetLoop('_atom_site_label')
+        anisotropy_already_set = (
+            atom_site_loop.has_key('_atom_site_adp_type') or
+            atom_site_loop.has_key('_atom_site_thermal_displace_type'))
         # something to do here:
         adp_loop = block.GetLoop('_atom_site_aniso_label')
         # index of the _atom_site_label column
@@ -389,6 +409,8 @@ class P_cif(StructureParser):
         for values in sitedatalist:
             idx = self.labelindex[values[ilb]]
             a = self.stru[idx]
+            if not anisotropy_already_set:
+                a.anisotropy = True
             for fset, val in zip(prop_setters, values):
                 fset(a, val)
         return
@@ -415,7 +437,7 @@ class P_cif(StructureParser):
             # sym_loop exists here and we know its cif name
             sym_loop_name = sym_loop_name[0]
             sym_loop = block.GetLoop(sym_loop_name)
-            for eqxyz in sym_loop.GetLoopItem(sym_loop_name):
+            for eqxyz in sym_loop[sym_loop_name]:
                 op = getSymOp(eqxyz)
                 symop_list.append(op)
         # determine space group number
@@ -467,7 +489,8 @@ class P_cif(StructureParser):
         # get reverse-ordered unique indices
         corepos = [a.xyz for a in self.stru]
         coreUijs = [a.U for a in self.stru]
-        self.eau = ExpandAsymmetricUnit(self.spacegroup, corepos, coreUijs)
+        self.eau = ExpandAsymmetricUnit(self.spacegroup, corepos, coreUijs,
+                                        eps=self.eps)
         # build a nested list of new atoms:
         newatoms = []
         for i, ca in enumerate(self.stru):
@@ -651,7 +674,65 @@ def fixIfWindowsPath(filename):
     return fixedname
 
 
-def getParser():
-    return P_cif()
+class _FixPyCifRW(object):
+
+    """Uniform interface helper for various PyCifRW versions.
+    """
+
+    _isversion4 = None
+    _yapps3_print_error = None
+    _yapps3_module = None
+
+    def isVersion4(self):
+        "True if the installed PyCifRW is at least 4.0 or later."
+        import pkg_resources
+        cls = _FixPyCifRW
+        if cls._isversion4 is None:
+            dist = pkg_resources.get_distribution('PyCifRW')
+            v4 = pkg_resources.parse_version('4')
+            cls._isversion4 = (dist.parsed_version >= v4)
+        return cls._isversion4
+
+
+    def importStarError(self):
+        "Import and return the StarError exception from PyCifRW."
+        if self.isVersion4():
+            from CifFile.StarFile import StarError
+        else:
+            from StarFile import StarError
+        return StarError
+
+
+    def disableParserOutput(self):
+        """Disable PyCifRW output due to CIF parsing errors.
+        """
+        if not self.isVersion4():  return
+        cls = _FixPyCifRW
+        if cls._yapps3_module is None:
+            import CifFile.yapps3_compiled_rt as mod
+            cls._yapps3_module = mod
+            cls._yapps3_print_error = mod.print_error
+        noop = lambda *a, **kw : None
+        cls._yapps3_module.print_error = noop
+        return
+
+
+    def restoreParserOutput(self):
+        """Restore PyCifRW output as implemented.
+        """
+        if not self.isVersion4():  return
+        cls = _FixPyCifRW
+        assert cls._yapps3_print_error is not None
+        cls._yapps3_module.print_error = cls._yapps3_print_error
+        return
+
+
+def getParser(eps=None):
+    """Return new parser object for CIF structure format.
+
+    eps  -- fractional coordinates cutoff for duplicate positions.
+            When None use the default for ExpandAsymmetricUnit.
+    """
+    return P_cif(eps=eps)
 
 # End of file
